@@ -1,3 +1,5 @@
+from __future__ import division
+
 import gzip
 import os
 import sys
@@ -176,6 +178,12 @@ class _File(object):
                 # For output stream start with a truncated file.
                 self.size = 0
             elif isinstance(self.__file, gzip.GzipFile):
+                # This gives the size of the actual file, but it's not too
+                # useful since the semantics of this really should be the size
+                # of the compressed file.  Unfortunately there's no way to get
+                # that with decompressing the file first.
+                # TODO: Make .size into a lazyproperty that, for compressed
+                # files, will just decompress the file and give the actual size
                 pos = self.__file.tell()
                 self.__file.fileobj.seek(0, 2)
                 self.size = self.__file.fileobj.tell()
@@ -242,7 +250,7 @@ class _File(object):
                                  '%s' % (size, shape, dtype))
 
         if size and not shape:
-            shape = (size / dtype.itemsize,)
+            shape = (size // dtype.itemsize,)
 
         if not (size or shape):
             warnings.warn('No size or shape given to readarray(); assuming a '
@@ -297,11 +305,14 @@ class _File(object):
         else:
             self.__file.seek(offset, whence)
 
-        pos = self.__file.tell()
+        if self.compressed:
+            pos = self.__file.fileobj.tell()
+        else:
+            pos = self.__file.tell()
         if pos > self.size:
-            warnings.warn('Warning: File may have been truncated: actual '
-                          'file length (%i) is smaller than the expected '
-                          'size (%i)' % (self.size, pos))
+            warnings.warn('File may have been truncated: actual file length '
+                          '(%i) is smaller than the expected size (%i)' %
+                          (self.size, pos))
 
     def tell(self):
         if not hasattr(self.__file, 'tell'):
